4.4. oncilla.globals.constants — Oncilla 0.1.0 documentation

# 4.4. oncilla.globals.constants

constants.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines Oncilla package default constants through the `Constants` class.

Others:

## 4.4.1. Classes

class `oncilla.globals.constants.` `Constants`

  Defines Oncilla package default constants.

  `applicationName` = u'Oncilla'

    Parameters: | applicationName (unicode) – Package Application name.

  `majorVersion` = u'0'

    Parameters: | majorVersion (unicode) – Package major version.

  `minorVersion` = u'1'

    Parameters: | minorVersion (unicode) – Package minor version.

  `changeVersion` = u'0'

    Parameters: | changeVersion (unicode) – Package change version.

  `version` = u'0.1.0'

    Parameters: | version (unicode) – Package version.

  `logger` = u'Oncilla_Logger'

    Parameters: | logger (unicode) – Package logger name.

  `verbosityLevel` = 3

    Parameters: | verbosityLevel (int) – Default logging verbosity level.

  `verbosityLabels` = (u'Critical', u'Error', u'Warning', u'Info', u'Debug')

    Parameters: | verbosityLabels (tuple) – Logging verbosity labels.

  `loggingDefaultFormatter` = u'Default'

    Parameters: | loggingDefaultFormatter (unicode) – Default logging formatter name.

  `loggingSeparators` = u'************************************************************************************************'

    Parameters: | loggingSeparators (unicode) – Logging separators.

  `defaultCodec` = 'utf-8'

    Parameters: | defaultCodec (unicode) – Default codec.

  `codecError` = u'ignore'

    Parameters: | codecError (unicode) – Default codec error behavior.